#meta analysis update

######libraries and data####
library(compute.es)
library(tidyverse)



##load in data behavioural ####

data <- read_csv("behavioural.csv") %>% 
data$outcome__1 <- as.numeric(recode(data$outcome__1, RT = '9'))
qa <- read_csv("QA.csv") %>% 
  select(PaperID, `average scores`)
qa <- qa[-(48:53),]
qa[32,1] <- 'd3' #rename so that they match with behavioural dataset
qa[31,1] <- 'd19'
qa[46,1] <- 'R272'

#separate datasets for the different statistics
d.m <- data %>% filter(is.na(m.asd)==F) #means
d.t <- data %>% filter(is.na(`t-test`)==F) %>% 
  anti_join(d.m, by = "t-test") # t-tests but not containing means
d.cohen <- data %>% filter(is.na(`cohen'sd`)==F) %>% 
  anti_join(d.t, by = "cohen'sd") %>% 
  anti_join(d.m, by = "cohen'sd") #cohen's d but not t-test or means 

# get the effect size alculated with compute.es functions
es.data.m <- mes(m.2=m.asd, m.1 = m.td, sd.2 = sd.asd, sd.1 = sd.td, 
                 n.2 = nASD, n.1 = nTD, level=95, dig=2, id=`outcome`, data=d.m)
es.data.t <- tes(t=`t-test`, n.2 = nASD, n.1 = nTD, id=`outcome`, data=d.t )
es.data.cohen <- des(d=`cohen'sd`, n.2 = nASD, n.1 = nTD, id=`outcome`, data=d.cohen)

#select only the Hedges g relevant information
es.data.m <- rename(es.data.m, `outcome` = id) %>% 
  select(`outcome`, N.total, g, var.g) %>% 
  inner_join(data, "outcome") %>% 
  select(-c(m.asd, m.td,sd.asd,sd.td, `t-test`, `cohen'sd`, `Other tests`))

es.data.t <- rename(es.data.t, `outcome` = id) %>% 
  select(`outcome`, N.total, g, var.g) %>% 
  inner_join(data, "outcome") %>% 
  select(-c(m.asd, m.td,sd.asd,sd.td, `t-test`, `cohen'sd`, `Other tests`))

es.data.cohen <- rename(es.data.cohen, `outcome` = id) %>% 
  select(`outcome`, N.total, g, var.g) %>% 
  inner_join(data, "outcome") %>% 
  select(-c(m.asd, m.td,sd.asd,sd.td, `t-test`, `cohen'sd`, `Other tests`))

#combine data and check whether the effect should be  positive or negative
#positive means petter performance for the NT group, 
#negative means better performance for ASD group
es.data <- bind_rows(es.data.m, es.data.t, es.data.cohen) %>% 
  mutate(g=ifelse(`ASD>TD=1, ASD<TD=2 (performance)`==2, abs(g), ifelse(g<0,g,g*(-1))), w=(1/var.g))

#outliers check
boxplot(es.data$g) # 4 top outliers 1 bottom
top_n(es.data, 4, g)


#reconnect data with the rest of the relevant information and tidyup
es.data2 <- bind_rows(es.data.m, es.data.t, es.data.cohen) %>% 
  mutate(g = ifelse(`ASD>TD=1, ASD<TD=2 (performance)`==2, abs(g), 
                  ifelse(g<0,g,g*(-1))),
         w = (1/var.g),
         case=1:length(g)) %>% 
  rename('StudyID'     =`Study ID`, 
         'females_asd' = `%females.asd`,
         'females_td'  = `%females.td`, 
         'totalN'      = N.total) %>% 
  select(-c(`ASD>TD=1, ASD<TD=2 (performance)`, `type of study`))%>% 
  select(-c(viq_asd, viq_td, age_asd, age_td)) %>% 
  rename(PaperID = "StudyID") %>% 
  left_join(qa, c("PaperID")) %>% 
  rename(QA = 'average scores') %>% 
  select(-PaperID)


es.data3 <- es.data2 %>% select(-c(females_asd, females_td, fsiq_asd, fsiq_td, nviq_asd, nviq_td, age_cat_asd, age_cat_td)) %>% 
  mutate(paradigm = ifelse(paradigm==1, 2, paradigm)) # combine paradime 1 and 2


write_csv(es.data3, "es_data_wRT.csv") 

#data without RT
es.data4 <- es.data3 %>% filter(outcome__1 !=9)
boxplot(es.data4$g)
write_csv(es.data4, "es_data_noRT.csv")

# 4 top outliers 1 bottom
top_n(es.data4, 5, g)
es.data.1 <- es.data4 %>% filter(!(outcome %in% c(1.20, 1.30, 15.10, 29.30, 33.10))) # remove outliers

write_csv(es.data.1, "es_data_noRT_noout.csv")

#only RT
es.data5 <- es.data3 %>% filter(outcome__1 ==9)
boxplot(es.data5$g)

write_csv(es.data5, "es_data_RT.csv")

#RT data no outliers
top_n(es.data5, 2, g)
top_n(es.data5, -1, g)

es.data.2 <- es.data5 %>% filter(!(outcome %in% c(17.20, 29.2, 29.4))) # remove outliers
write_csv(es.data.2, "es_data_RT_noout.csv")


###########create females datasets##########

female <- es.data2 %>% filter(is.na(females_asd) == F & is.na(females_td) == F) %>% 
  select(-c(fsiq_asd, fsiq_td, nviq_asd, nviq_td)) %>% 
  mutate(females_asd = scale(females_asd, scale = F), females_td = scale(females_td, scale = F))
write_csv(female, "female.csv") 

female_noRT <- es.data2 %>% filter(is.na(females_asd) == F & is.na(females_td) == F) %>% 
  select(-c(fsiq_asd, fsiq_td, nviq_asd, nviq_td)) %>% 
  mutate(females_asd = scale(females_asd, scale = F), females_td = scale(females_td, scale = F)) %>% 
  filter(outcome__1 !=9)
write_csv(female_noRT, "female_noRT.csv") 

female_noRT <- es.data.1 %>% filter(is.na(females_asd) == F & is.na(females_td) == F) %>% 
  select(-c(fsiq_asd, fsiq_td, nviq_asd, nviq_td)) %>% 
  mutate(females_asd = scale(females_asd, scale = F), females_td = scale(females_td, scale = F)) %>% 
  filter(outcome__1 !=9)
write_csv(female_noRT, "female_noRT_noout.csv") 

female_RT <- es.data2 %>% filter(is.na(females_asd) == F & is.na(females_td) == F) %>% 
  select(-c(fsiq_asd, fsiq_td, nviq_asd, nviq_td)) %>% 
  mutate(females_asd = scale(females_asd, scale = F), females_td = scale(females_td, scale = F)) %>% 
  filter(outcome__1 ==9)
write_csv(female_RT, "female_RT.csv")


########create fsiq dataset########

fsiq <- filter(es.data2, is.na(fsiq_asd)== F & is.na(fsiq_td)== F) %>% 
  select(-c(females_asd, females_td, nviq_asd, nviq_td)) %>% 
  mutate(fsiq_asd = scale(fsiq_asd, scale = F), fsiq_td = scale(fsiq_td, scale = F))

write.csv(fsiq, "fsiq_only.csv")

fsiq_noRT <- filter(es.data2, is.na(fsiq_asd)== F & is.na(fsiq_td)== F) %>% 
  select(-c(females_asd, females_td, nviq_asd, nviq_td)) %>% 
  mutate(fsiq_asd = scale(fsiq_asd, scale = F), fsiq_td = scale(fsiq_td, scale = F)) %>% 
  filter(outcome__1 !=9)

write.csv(fsiq_noRT, "fsiq_only_noRT.csv")

fsiq_noRT <- filter(es.data.1, is.na(fsiq_asd)== F & is.na(fsiq_td)== F) %>% 
  select(-c(females_asd, females_td, nviq_asd, nviq_td)) %>% 
  mutate(fsiq_asd = scale(fsiq_asd, scale = F), fsiq_td = scale(fsiq_td, scale = F)) %>% 
  filter(outcome__1 !=9)

write.csv(fsiq_noRT, "fsiq_only_noRT_noout.csv")

fsiq_RT <- filter(es.data2, is.na(fsiq_asd)== F & is.na(fsiq_td)== F) %>% 
  select(-c(females_asd, females_td, nviq_asd, nviq_td)) %>% 
  mutate(fsiq_asd = scale(fsiq_asd, scale = F), fsiq_td = scale(fsiq_td, scale = F)) %>% 
  filter(outcome__1 ==9)

write.csv(fsiq_RT, "fsiq_only_RT.csv")


########create nviq dataset########
nviq <- filter(es.data2, is.na(nviq_asd)== F & is.na(nviq_td)== F) %>% 
  select(-c(females_asd, females_td, fsiq_asd, fsiq_td))%>% 
  mutate(nviq_asd = scale(nviq_asd, scale = F), nviq_td = scale(nviq_td, scale = F))

write.csv(nviq, "nviq_only.csv")

nviq_noRT <- filter(es.data2, is.na(nviq_asd)== F & is.na(nviq_td)== F) %>% 
  select(-c(females_asd, females_td, fsiq_asd, fsiq_td))%>% 
  mutate(nviq_asd = scale(nviq_asd, scale = F), nviq_td = scale(nviq_td, scale = F)) %>% 
  filter(outcome__1 !=9)

write.csv(nviq_noRT, "nviq_only_noRT.csv")

nviq_noRT <- filter(es.data.1, is.na(nviq_asd)== F & is.na(nviq_td)== F) %>% 
  select(-c(females_asd, females_td, fsiq_asd, fsiq_td))%>% 
  mutate(nviq_asd = scale(nviq_asd, scale = F), nviq_td = scale(nviq_td, scale = F)) %>% 
  filter(outcome__1 !=9)

write.csv(nviq_noRT, "nviq_only_noRT_noout.csv")

nviq_RT <- filter(es.data2, is.na(nviq_asd)== F & is.na(nviq_td)== F) %>% 
  select(-c(females_asd, females_td, fsiq_asd, fsiq_td))%>% 
  mutate(nviq_asd = scale(nviq_asd, scale = F), nviq_td = scale(nviq_td, scale = F)) %>% 
  filter(outcome__1 ==9)

write.csv(nviq_RT, "nviq_only_RT.csv")


#######eye-tracking########
eye.tracking <- read_csv("eye_tracking.csv")

#get means 
et.m <- eye.tracking %>% filter(is.na(m.asd)==F)

#get Hedges g
et.es.m <- mes(m.2=m.asd, m.1 = m.td, sd.2 = sd.asd, sd.1 = sd.td, 
            n.2 = nASD, n.1 = nTD, level=95, dig=2, id=`outcome`, data=et.m)

# tidy up and connect with rest of information
et.es.m <- rename(et.es.m, `outcome` = id) %>% 
  select(`outcome`, N.total, g, var.g) %>% 
  inner_join(eye.tracking, "outcome") %>% 
  select(-c(m.asd, m.td,sd.asd,sd.td, `t-test`, `cohen'sd`))

# get t-tests
et.t <- eye.tracking %>% filter(is.na(`t-test`)==F) %>% 
  anti_join(et.m, by = "t-test")

#get Hedges g
et.es.t <- tes(t=`t-test`, n.2 = nASD, n.1 = nTD, id=`outcome`, data=et.t )


# tidy up and connect with rest of information
et.es.t <- rename(et.es.t, `outcome` = id) %>% 
  select(`outcome`, N.total, g, var.g) %>% 
  inner_join(eye.tracking, "outcome") %>% 
  select(-c(m.asd, m.td,sd.asd,sd.td, `t-test`, `cohen'sd`))

#connect all data together
et.data <- bind_rows(et.es.m, et.es.t) %>% 
  mutate(g    = ifelse(`ASD>TD=1, ASD<TD=2 ( performance)`==2, abs(g), 
                    ifelse(g<0, g, g*(-1))), 
         w    = (1/var.g),
         case = 1:length(g)) %>% 
  rename('females_asd' = `%females.asd`, 
         'females_td'  = `%females.td`, 
         'totalN'      = N.total) %>% 
  select(-c(`ASD>TD=1, ASD<TD=2 ( performance)`, `type of study`,  
            StudyID, viq_asd, viq_td, age_asd, age_td, age_cat_td, 
            females_asd, females_td, nviq_asd, nviq_td, fsiq_asd, fsiq_td))


#plot to see how it looks
boxplot(et.data$g)
write_csv(et.data, "et_data.csv")


### EEG ####

eeg <- read_csv("eeg.csv")

#get means
eeg.m <- eeg %>% filter(is.na(m.asd)==F)

#get Hedges g
eeg.es.m <- mes(m.2=m.asd, m.1 = m.td, sd.2 = sd.asd, sd.1 = sd.td, 
               n.2 = nASD, n.1 = nTD, level=95, dig=2, id=`outcome`, data=eeg.m)

#tidy-up
eeg.es.m <- rename(eeg.es.m, `outcome` = id) %>% 
  select(`outcome`, N.total, g, var.g) %>% 
  inner_join(eeg, "outcome") %>% 
  select(-c(m.asd, m.td,sd.asd,sd.td, `t-test`, `cohen'sd`))

#get t-tests
eeg.t <- eeg %>% filter(is.na(`t-test`)==F) %>% 
  anti_join(eeg.m, by = "t-test")

#get Hedges g
eeg.es.t <- tes(t=`t-test`, n.2 = nASD, n.1 = nTD, id=`outcome`, data=eeg.t )

#tidy up

eeg.es.t <- rename(eeg.es.t, `outcome` = id) %>% 
  select(`outcome`, N.total, g, var.g) %>% 
  inner_join(eeg, "outcome") %>% 
  select(-c(m.asd, m.td,sd.asd,sd.td, `t-test`, `cohen'sd`))

get quality assessment
qa$PaperID <-as.numeric(qa$PaperID)

#connect all data together
eeg.data <- bind_rows(eeg.es.m, eeg.es.t) %>% 
  mutate(g    = ifelse(`ASD>TD=1, ASD<TD=2 ( performance)`==2, abs(g), 
                       ifelse(g<0, g, g*(-1))), 
         w    = (1/var.g),
         case = 1:length(g)) %>% 
  rename('females_asd' = `%females.asd`, 
         'females_td'  = `%females.td`, 
         'totalN'      = N.total) %>% 
  left_join(qa, by =c('StudyID'= 'PaperID')) %>% 
  rename(QA = 'average scores') %>% 

  select(-c(`ASD>TD=1, ASD<TD=2 ( performance)`, `type of study`,  
            StudyID, viq_asd, viq_td, age_asd, age_td, age_cat_td, 
            females_asd, females_td, nviq_asd, nviq_td, fsiq_asd, fsiq_td))


#plot to see how it looks
boxplot(eeg.data$g)
write_csv(eeg.data, "eeg_data.csv")

## Run Analysis in SAS - seperate file




####funnel plot#####
  #- https://sakaluk.wordpress.com/2016/02/16/7-make-it-pretty-plots-for-meta-analysis/
es.data2 <- read_csv("es_data_noRT_noout.csv") 
  #Store the meta-analytic estimate and its standard error from whatever model you run (substitute your own values)
  estimate = 0.6066
  se = 0.1651
  
  es.data2$es <- (sqrt(es.data2$var.g)/sqrt(es.data2$totalN))
  #Store a vector of values that spans the range from 0
  #to the max value of impression (standard error) in your dataset.
  #Make the increment (the final value) small enough (I choose 0.001)
  #to ensure your whole range of data is captured
  se.seq=seq(0, max(es.data2$es), 0.001)
  
  #Get the 95% CI region, using the range of SE that you generated in the previous step, and the stored value of your meta-analytic estimate.
  ll95 = estimate-(1.96*se.seq)
  ul95 = estimate+(1.96*se.seq)
  meanll95 = estimate-(1.96*se)
  meanul95 = estimate+(1.96*se)
  
  #Combine in one  dataset
  dfCI = data.frame(ll95, ul95, se.seq, estimate, meanll95, meanul95)

  #Now we can actually make the funnel plot.
  #Using your original data-frame, map standard error to your x-axis (for now) and Hedges g to your y-axis
fp.0 <- ggplot(aes(x = es, y = g), data = es.data2) +
    #Add your data-points to the scatterplot
    geom_point(aes(shape = as.factor(age_cat_ASD_TD), color= as.factor(age_cat_ASD_TD)), data=es.data2, size = 2) +
    #Give the x- and y- axes informative labels
    xlab('Standard Error') + ylab('Hedge\'s g')+
    
    geom_line(aes(y = estimate)) +
    #Now plot lines corresponding to the 95% CI of your meta-analytic estimate
    geom_segment(aes(x = min(se.seq), y = estimate, xend = max(se.seq), yend = meanll95), linetype='dotted', data=dfCI) +
    geom_segment(aes(x = min(se.seq), y = estimate, xend = max(se.seq), yend = meanul95), linetype='dotted', data=dfCI) +
    #Reverse the x-axis ordering (es) so that the tip of the funnel will appear
    #at the top of the figure once we swap the x- and y-axes...
    scale_x_reverse() +
    scale_shape_discrete(name="Age",
                         breaks=c("1", "2", "3"),
                         labels=c("<= 13", "between 13 & 19", " > 19")) +
    scale_colour_discrete(name="Age",
                          breaks=c("1", "2", "3"),
                          labels=c("<= 13", "between 13 & 19", " > 19")) +                     
    #Specify the range and interval for the tick-marks of the y-axis (Zr);
    #Choose values that work for you based on your data
    scale_y_continuous(breaks=seq(-0.5,2.5,0.5)) +
    #And now we flip the axes so that SE is on y- and Hedges g is on x-
    coord_flip() +
    theme_minimal() +
    theme(axis.text.x = element_text(size=14),
          axis.text.y = element_text(size=14),
          axis.title.x = element_text(size=16,face="bold"),
          axis.title.y = element_text(size=16,face="bold"),
          legend.text = element_text(size = 14),
          legend.title = element_text(size = 14, face = 'plain'),
          strip.text.y = element_text(size = 14),
          panel.grid.minor = element_blank(), 
          legend.position = 'top') 
   
 fp.0
 ggsave('funnel_v2.eps', width=6.5, height=5, dpi=1200)
 
  

####forest####

es.data2<- es.data.2 #select the appropriate data for each plot

es.data2$lowerci <- (-1.96*(sqrt(es.data2$var.g)/sqrt(es.data2$totalN)))+es.data2$g
es.data2$upperci <- (1.96*(sqrt(es.data2$var.g)/sqrt(es.data2$totalN)))+es.data2$g
es.data2 <- mutate(es.data2, paradigm = ifelse(paradigm==1, 2, paradigm))
labels <- c("2" = "BM detection", "3" = "Action", "4" = "Emotion")

#Make a plot called 'p', and map citation data to y-axis, effect sizes to x-axis # some of the column names differ between the datasets
#specify the min and max of the CIs, and give different shapes & colours based on levels of tester
p<-ggplot(es.data2, aes(y=`Study and year`, x=g, xmin=lowerci, xmax=upperci, shape = as.factor(age_cat_ASD_TD), color= as.factor(age_cat_ASD_TD))) +
  #Add data points and color them black
  geom_point(size = 2) +

  #add the CI error bars
  geom_errorbarh(height=.2)+
  #Specify the limits of the x-axis depending on the dataset used
  scale_x_continuous(breaks = c(-1:3,0.729),limits = c(-1,2), name='Hedge\'s g (g)')+
  #Give y-axis a meaningful label
  ylab('Reference')+
  #Add a vertical dashed line indicating the effect size and one for zero, for reference
  geom_vline(xintercept=0, color='black')+
  #change based on the overall effect size
  geom_vline(xintercept = 0.6066, color = 'black', linetype = 6) +
  
  #Create facets based on levels of paradigm
  #And allow them to have their own unique axes 
  facet_grid(paradigm~., scales= 'free', space='free', labeller=labeller(paradigm = labels)) +
  scale_shape_discrete(name="Age",
                        breaks=c("1", "2", "3"),
                        labels=c("<= 13", "between 13 & 19", " > 19")) +
  scale_colour_discrete(name="Age",
                       breaks=c("1", "2", "3"),
                       labels=c("<= 13", "between 13 & 19", " > 19")) +
  theme_bw() +
  theme(axis.text.x = element_text(size=14),
        axis.text.y = element_text(size=14),
        axis.title.x = element_text(size=16,face="bold"),
        axis.title.y = element_text(size=16,face="bold"),
        legend.text = element_text(size = 14),
        legend.title = element_text(size = 14, face = 'plain'),
        strip.text.y = element_text(size = 14),
        panel.grid.minor = element_blank(), 
        legend.position = 'top')
p

ggsave('forrest.pdf', width=8.5, height=8, dpi=600)


#for creating the combined plot 3 searate plot vaiables are necessary reaction time, Eye-tracking, EEG
cowplot::plot_grid(prt, pet, peeg, align = 'v',labels = c('A', 'B', 'C'), 
                   nrow=3, ncol =  1, rel_heights = c(1.9,2.5,1),
                   label_y = c(1,1,1.1), label_colour = 'blue')

ggsave('forrest3.pdf', width=8.5, height=10, dpi=1200)