* set the library;
LIBNAME SR	"XXXXXXXX" ;

* change XXXXXX to the location of the dataset. To change to use different files;
FILENAME ref_RT 'XXXXXXX/es_data_noRT_noout.csv';


PROC IMPORT DATAFILE=ref_RT
	DBMS=CSV
	OUT=es_data
	REPLACE;
RUN;


*overal effect size;
proc mixed data=es_data method = ml COVTEST;
		class Study case;
		model g= /solution cl ddfm=satterthwaite;
		weight w; 
		random intercept/sub=Study;
		random intercept/sub= case(Study);
		
run;
* effect of quality assessment (use QA as an additional variable to see difference);
proc mixed data=es_data method = ml COVTEST;
		class Study case;
		model g= QA/solution cl ddfm=satterthwaite;
		weight w; 
		random intercept/sub=Study;
		random intercept/sub= case(Study);
		
run;

* effect of paradigm;
proc mixed data=es_data method = ml COVTEST;
		class Study case paradigm;
		model g= paradigm/solution cl  ddfm=satterthwaite;
		weight w;
		random intercept/sub=Study;
		random intercept/sub=case(Study); /*does not converge with case(Study) but results do not change*/ 
		lsmeans paradigm/ e cl diff=all;
		
run; 

*effect and interaction of paradigm and age;
proc mixed data=es_data method = ml COVTEST;
		class Study case paradigm age_cat_ASD_TD;
		model g= paradigm age_cat_ASD_TD paradigm*age_cat_ASD_TD/solution cl ddfm=satterthwaite;
		weight w;
		random intercept/sub=Study ;
		random intercept/sub=case(Study);
		lsmeans age_cat_ASD_TD paradigm*age_cat_ASD_TD / e cl diff=all;
run;



* run for the stimuli without the one that has pld and full light together;
data es_data;
  set es_data;
  if outcome eq 7.1

   then delete;

run;

proc mixed data=es_data method = ml COVTEST;
		class Study case stimuli;
		model g= stimuli/solution cl ddfm=sat;
		weight w;
		random intercept/sub=Study;
		random intercept/sub=case(Study);
		lsmeans stimuli/ e cl diff=all;
		
run;

*load the female dataset;
FILENAME fem 'XXXXX/female.csv';


PROC IMPORT DATAFILE=fem
	DBMS=CSV
	OUT=REFFILEw
	replace;
	GETNAMES=YES;

RUN;


* effect of ASD females in dataset;
proc mixed data=REFFILEw method = ml COVTEST; 
		class Study case;
		model g= females_asd/solution cl ddfm=satterthwaite;
		weight w;
		random intercept/sub=Study;
		random intercept/sub=case(Study);
		
run;


* effect of NT females in dataset;
proc mixed data=REFFILEw method = ml COVTEST;
		class Study case;
		model g= females_td/solution cl ddfm=satterthwaite;
		weight w;
		random intercept/sub=Study;
		random intercept/sub=case(Study);
		
run;

* fsiq for asd and nt with ones that have fsiq available data;
FILENAME fsiqnrt 'XXXXXX/fsiq_only_noRT_noout.csv';


PROC IMPORT DATAFILE=fsiqnrt
	DBMS=CSV
	OUT=fsiq_datanrt
	replace;
	GETNAMES=YES;
RUN;

* effect of ASD fsiq;

proc mixed data=fsiq_datanrt method=ml COVTEST;
		class Study case;
		model g= fsiq_asd /solution cl ddfm=satterthwaite;
		weight w; 
		random intercept/sub=Study;
		random intercept/sub= case(Study);
		
run;
* effect of NT fsiq;
proc mixed data=fsiq_datanrt method=ml COVTEST;
		class Study case;
		model g= fsiq_td /solution cl ddfm=satterthwaite;
		weight w; 
		random intercept/sub=Study;
		random intercept/sub= case(Study);
		
run;

* nviq for asd and nt with ones that have nviq available data;
FILENAME niqnrt 'XXXXXX/nviq_only_noRT_noout.csv';


PROC IMPORT DATAFILE=niqnrt
	DBMS=CSV
	OUT=nviq_datanrt
	replace;
	GETNAMES=YES;
RUN;

* effect of ASD nviq;
proc mixed data=nviq_datanrt method=ml COVTEST;
		class Study case;
		model g= nviq_asd /solution cl ddfm=satterthwaite;
		weight w; 
		random intercept/sub=Study;
		random intercept/sub= case(Study);
		
run;

* effect of NT nviq;
proc mixed data=nviq_datanrt method=ml COVTEST;
		class Study case;
		model g= nviq_td /solution cl ddfm=satterthwaite;
		weight w; 
		random intercept/sub=Study;
		random intercept/sub= case;
		
run;

* eye tracking data ;
FILENAME eye 'XXXXXX/et_data.csv';
PROC IMPORT DATAFILE=eye
	DBMS=CSV
	OUT=et_data
	replace;
	GETNAMES=YES;
RUN;

*main effect in the eye tracking dataset;
proc mixed data=et_data method = ml COVTEST;
		class study case;
		model g= /solution ddfm=sat;
		weight w; 
		random intercept/sub=study;
		random intercept/sub= case(study);
		
run;




* eeg  data ;
FILENAME eeg 'XXXXXX/eeg_data2.csv';
PROC IMPORT DATAFILE=eeg
	DBMS=CSV
	OUT=eeg_data
	replace;
	GETNAMES=YES;
RUN;

*main effect in the eeg dataset

proc mixed data=eeg_data method = ml COVTEST;
		class study case;
		model g= /solution cl ddfm=sat;
		weight w; 
		random intercept/sub=study;
		random intercept/sub= case(study);
		
run;

*QA effect on eeg findings;

proc mixed data=eeg_data method = ml COVTEST;
		class study case;
		model g= QA/solution cl ddfm=sat;
		weight w; 
		random intercept/sub=study;
		random intercept/sub= case(study);
		
run;

*Effect of frequency (exploratory);

proc mixed data=eeg_data method = ml COVTEST;
		class study case frequency;
		model g= frequency/solution cl ddfm=sat;
		weight w; 
		random intercept/sub=study;
		random intercept/sub= case(study);
		lsmeans frequency/ e cl diff=all;
run;